# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.combat_log import CombatLog

class TestCombatLog(unittest.TestCase):
    """CombatLog unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CombatLog:
        """Test CombatLog
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CombatLog`
        """
        model = CombatLog()
        if include_optional:
            return CombatLog(
                id = 56,
                metadata = OSCR_django_client.models.metadata.Metadata(
                    id = 56, 
                    map = '0', 
                    difficulty = '0', 
                    summary = OSCR_django_client.models.summary.Summary(), 
                    date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                youtube = '0'
            )
        else:
            return CombatLog(
                metadata = OSCR_django_client.models.metadata.Metadata(
                    id = 56, 
                    map = '0', 
                    difficulty = '0', 
                    summary = OSCR_django_client.models.summary.Summary(), 
                    date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testCombatLog(self):
        """Test CombatLog"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.api.combatlog_api import CombatlogApi


class TestCombatlogApi(unittest.TestCase):
    """CombatlogApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CombatlogApi()

    def tearDown(self) -> None:
        pass

    def test_combatlog_download(self) -> None:
        """Test case for combatlog_download

        Combat Log Download
        """
        pass

    def test_combatlog_list(self) -> None:
        """Test case for combatlog_list

        """
        pass

    def test_combatlog_read(self) -> None:
        """Test case for combatlog_read

        """
        pass

    def test_combatlog_upload(self) -> None:
        """Test case for combatlog_upload

        Combat Log Upload
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.3"

# import apis into sdk package
from OSCR_django_client.api.combatlog_api import CombatlogApi
from OSCR_django_client.api.ladder_api import LadderApi
from OSCR_django_client.api.ladder_entries_api import LadderEntriesApi
from OSCR_django_client.api.variant_api import VariantApi

# import ApiClient
from OSCR_django_client.api_response import ApiResponse
from OSCR_django_client.api_client import ApiClient
from OSCR_django_client.configuration import Configuration
from OSCR_django_client.exceptions import OpenApiException
from OSCR_django_client.exceptions import ApiTypeError
from OSCR_django_client.exceptions import ApiValueError
from OSCR_django_client.exceptions import ApiKeyError
from OSCR_django_client.exceptions import ApiAttributeError
from OSCR_django_client.exceptions import ApiException

# import models into sdk package
from OSCR_django_client.models.combat_log import CombatLog
from OSCR_django_client.models.combat_log_upload_response import CombatLogUploadResponse
from OSCR_django_client.models.combatlog_list200_response import CombatlogList200Response
from OSCR_django_client.models.ladder import Ladder
from OSCR_django_client.models.ladder_entries_list200_response import LadderEntriesList200Response
from OSCR_django_client.models.ladder_entry import LadderEntry
from OSCR_django_client.models.ladder_list200_response import LadderList200Response
from OSCR_django_client.models.metadata import Metadata
from OSCR_django_client.models.variant import Variant
from OSCR_django_client.models.variant_list200_response import VariantList200Response



# coding: utf-8

# flake8: noqa
"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from OSCR_django_client.models.combat_log import CombatLog
from OSCR_django_client.models.combat_log_upload_response import CombatLogUploadResponse
from OSCR_django_client.models.combatlog_list200_response import CombatlogList200Response
from OSCR_django_client.models.ladder import Ladder
from OSCR_django_client.models.ladder_entries_list200_response import LadderEntriesList200Response
from OSCR_django_client.models.ladder_entry import LadderEntry
from OSCR_django_client.models.ladder_list200_response import LadderList200Response
from OSCR_django_client.models.metadata import Metadata
from OSCR_django_client.models.variant import Variant
from OSCR_django_client.models.variant_list200_response import VariantList200Response



# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.api.variant_api import VariantApi


class TestVariantApi(unittest.TestCase):
    """VariantApi unit test stubs"""

    def setUp(self) -> None:
        self.api = VariantApi()

    def tearDown(self) -> None:
        pass

    def test_variant_list(self) -> None:
        """Test case for variant_list

        """
        pass

    def test_variant_read(self) -> None:
        """Test case for variant_read

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.ladder import Ladder

class TestLadder(unittest.TestCase):
    """Ladder unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Ladder:
        """Test Ladder
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Ladder`
        """
        model = Ladder()
        if include_optional:
            return Ladder(
                id = 56,
                variant_name = '',
                name = '0',
                difficulty = '0',
                is_solo = True,
                is_space = True,
                metric = '0',
                variant = ''
            )
        else:
            return Ladder(
                name = '0',
                metric = '0',
                variant = '',
        )
        """

    def testLadder(self):
        """Test Ladder"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
